@@ -11,6 +11,7 @@
 """This module contains objects for low-level representation of lattice systems."""
 
 import logging
+import warnings
 from copy import deepcopy
 from typing import Union, Sequence
 import numpy as np
@@ -34,12 +35,20 @@ class DataMap:
         An array of index-pairs of the lattice sites.
     distindices : (M) np.ndarray
         The distance-indices for each pair
+
+    Notes
+    -----
+    This object is not intended to be instantiated by the user. Use the ``map`` method
+    of ``latticeData`` or the ``dmap`` method of the main ``Lattice```object.
     """
 
     def __init__(self, alphas: np.ndarray, pairs: np.ndarray, distindices: np.ndarray):
         sites = np.arange(len(alphas), dtype=pairs.dtype)
-        self._map = np.append(-alphas - 1, distindices)
-        self._indices = np.append(np.tile(sites, (2, 1)).T, pairs, axis=0)
+        map_ = np.append(-alphas - 1, distindices)
+        indices_ = np.append(np.tile(sites, (2, 1)).T, pairs, axis=0)
+        ind = np.argsort(indices_[:, 0])
+        self._map = map_[ind]
+        self._indices = indices_[ind]
 
     @property
     def size(self) -> int:
@@ -66,6 +75,35 @@ class DataMap:
         """The number of bytes stored in the datamap."""
         return self._map.nbytes + self._indices.nbytes
 
+    def indices_indptr(self):
+        """Constructs the `indices` and `indptr` arrays used for CSR/BSR matrices.
+
+        CSR/BSR sparse matrix format:
+        The block column indices for row i are stored in
+        ``indices[indptr[i]:indptr[i+1]]`` and their corresponding block values are
+        stored in ``data[indptr[i]: indptr[i+1]]``.
+
+        Returns
+        -------
+        indices : (N, ) np.ndarray
+            CSR/BSR format index array.
+        indptr : (M, ) np.ndarray
+            CSR/BSR format index pointer array.
+
+        See Also
+        --------
+        scipy.sparse.csr_matrix : Compressed Sparse Row matrix
+        scipy.sparse.bsr_matrix : Block Sparse Row matrix
+        """
+        rows, cols = self._indices.T
+        indptr, indices = [0], []
+        unique = np.sort(np.unique(rows))
+        for r in unique:
+            mask = rows == r
+            indices.extend(list(cols[mask]))
+            indptr.append(len(indices))
+        return indices, indptr
+
     def onsite(self, alpha: int = None) -> np.ndarray:
         """Creates a mask of the site elements for the atoms with the given index.
 
@@ -121,7 +159,14 @@ class DataMap:
         Returns
         -------
         filled : np.ndarray
+
+        .. deprecated:: 0.7.1
+          The `fill` method will be removed in LattPy 0.8.0
         """
+        warnings.warn(
+            "The `fill` method is deprecated and will be removed in a version '0.8.0'",
+            DeprecationWarning,
+        )
         eps = np.atleast_1d(eps)
         hop = np.atleast_1d(hop)
         for alpha, value in enumerate(eps):
@@ -130,6 +175,9 @@ class DataMap:
             array[self.hopping(dist)] = value
         return array
 
+    def __repr__(self):
+        return f"{self.__class__.__name__}(size: {self.size})"
+
 
 class LatticeData:
     """Object for storing the indices, positions and neighbors of lattice sites.
