@@ -21,12 +21,23 @@ from matplotlib.collections import LineCollection, Collection
 from mpl_toolkits.mplot3d.art3d import Line3DCollection, Line3D, Poly3DCollection
 from matplotlib.artist import allow_rasterization
 from matplotlib import path, transforms
+from typing import List
 import colorcet as cc
 
 __all__ = [
-    "subplot", "draw_line", "draw_lines", "hide_box",
-    "draw_arrows", "draw_vectors", "draw_points", "draw_indices", "draw_unit_cell",
-    "draw_surfaces", "interpolate_to_grid", "draw_sites"
+    "subplot",
+    "draw_line",
+    "draw_lines",
+    "hide_box",
+    "draw_arrows",
+    "draw_vectors",
+    "draw_points",
+    "draw_indices",
+    "draw_unit_cell",
+    "draw_surfaces",
+    "interpolate_to_grid",
+    "draw_sites",
+    "connection_color_array",
 ]
 
 # Golden ratio as standard ratio for plot-figures
@@ -107,10 +118,10 @@ def hide_box(ax, axis=False):
     if axis:
         for side in ["left", "bottom"]:
             ax.spines[side].set_visible(False)
-        ax.xaxis.set_ticks_position('none')
-        ax.yaxis.set_ticks_position('none')
-        ax.set_xlabel('')
-        ax.set_ylabel('')
+        ax.xaxis.set_ticks_position("none")
+        ax.yaxis.set_ticks_position("none")
+        ax.set_xlabel("")
+        ax.set_ylabel("")
         ax.set_xticks([])
         ax.set_yticks([])
 
@@ -119,6 +130,7 @@ def hide_box(ax, axis=False):
 # General Plotting
 # ======================================================================================
 
+
 def subplot(dim, adjustable="box", ax=None):
     """Generates a two- or three-dimensional subplot with a equal aspect ratio
 
@@ -369,7 +381,7 @@ def draw_points(ax, points, size=10, **kwargs):
     if points.shape[1] == 1:
         points = np.hstack((points, np.zeros((points.shape[0], 1))))
 
-    scat = ax.scatter(*points.T, s=size**2, **kwargs)
+    scat = ax.scatter(*points.T, s=size ** 2, **kwargs)
     # Manualy update data-limits
     # ax.ignore_existing_data_limits = True
     datalim = scat.get_datalim(ax.transData)
@@ -475,6 +487,7 @@ class CircleCollection(Collection):
     like a much faster version of a `PatchCollection` of `Circle`.
     The implementation is similar to `EllipseCollection`.
     """
+
     def __init__(self, radius, **kwargs):
         super().__init__(**kwargs)
         self.radius = np.atleast_1d(radius)
@@ -535,13 +548,21 @@ def draw_sites(ax, points, radius=0.2, **kwargs):
 
     dim = points.shape[1]
     if dim < 3:
-        col = CircleCollection(radius, offsets=points, transOffset=ax.transData,
-                               **kwargs)
+        col = CircleCollection(
+            radius, offsets=points, transOffset=ax.transData, **kwargs
+        )
         ax.add_collection(col)
         label = kwargs.get("label", "")
         if label:
-            ax.plot([], [], marker='o', lw=0, color=kwargs.get("color", None),
-                    label=label, markersize=10)
+            ax.plot(
+                [],
+                [],
+                marker="o",
+                lw=0,
+                color=kwargs.get("color", None),
+                label=label,
+                markersize=10,
+            )
         datalim = col.get_datalim(ax.transData)
         datalim.x0 -= radius
         datalim.x1 += radius
@@ -551,7 +572,7 @@ def draw_sites(ax, points, radius=0.2, **kwargs):
         return col
     else:
         size = radius * 50
-        scat = ax.scatter(*points.T, s=size**2, **kwargs)
+        scat = ax.scatter(*points.T, s=size ** 2, **kwargs)
         # Manualy update data-limits
         # ax.ignore_existing_data_limits = True
         datalim = scat.get_datalim(ax.transData)
@@ -559,6 +580,40 @@ def draw_sites(ax, points, radius=0.2, **kwargs):
         return scat
 
 
+def connection_color_array(num_base, default="k", colors=None) -> List[List]:
+    """Construct color array for the connections between all atoms in a lattice.
+
+    Parameters
+    ----------
+    num_base : int
+        The number of atoms in the unit cell of a lattice.
+    default : str or int or float or tuple
+        The default color of the connections.
+    colors : Sequence[tuple], optional
+        list of colors to override the defautl connection color. Each element
+        has to be a tuple with the first two elements being the atom indices of
+        the pair and the third element the color, for example ``[(0, 0, 'r')]``.
+
+    Returns
+    -------
+    color_array : List of List
+        The connection color array
+
+    Examples
+    --------
+    >>> connection_color_array(2, "k", colors=[(0, 1, "r")])
+    [['k', 'r'], ['r', 'k']]
+
+    """
+    alphas = range(num_base)
+    hop_colors = [[default for _ in alphas] for _ in alphas]
+    if colors is not None and colors:
+        for a1, a2, col in colors:
+            hop_colors[a1][a2] = col
+            hop_colors[a2][a1] = col
+    return hop_colors
+
+
 # noinspection PyShadowingNames
 def draw_indices(ax, positions, offset=0.05, **kwargs):
     """Draws the indices of the given positions on the plot.
@@ -644,8 +699,14 @@ def draw_unit_cell(ax, vectors, outlines=True, **kwargs):
     return arrows, lines
 
 
-def interpolate_to_grid(positions, values, num=(100, 100), offset=(0., 0.),
-                        method="linear", fill_value=np.nan):
+def interpolate_to_grid(
+    positions,
+    values,
+    num=(100, 100),
+    offset=(0.0, 0.0),
+    method="linear",
+    fill_value=np.nan,
+):
     x, y = positions.T
 
     # Create regular grid
